Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1982)

Unified Diff: chrome/browser/profiles/off_the_record_profile_io_data.cc

Issue 9617039: Change Origin bound certs -> Domain bound certs. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/net/ssl_config_service_manager_pref.cc ('k') | chrome/browser/profiles/profile_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/profiles/off_the_record_profile_io_data.cc
diff --git a/chrome/browser/profiles/off_the_record_profile_io_data.cc b/chrome/browser/profiles/off_the_record_profile_io_data.cc
index c21cb73751150e534c1b55710e06448970f50aab..89501824494f97aaf44f797d2f98743c681daeed 100644
--- a/chrome/browser/profiles/off_the_record_profile_io_data.cc
+++ b/chrome/browser/profiles/off_the_record_profile_io_data.cc
@@ -194,12 +194,12 @@ void OffTheRecordProfileIOData::LazyInitializeInternal(
http_server_properties_.reset(new net::HttpServerPropertiesImpl);
main_context->set_http_server_properties(http_server_properties_.get());
- // For incognito, we use a non-persistent origin bound cert store.
- net::OriginBoundCertService* origin_bound_cert_service =
- new net::OriginBoundCertService(
- new net::DefaultOriginBoundCertStore(NULL));
- set_origin_bound_cert_service(origin_bound_cert_service);
- main_context->set_origin_bound_cert_service(origin_bound_cert_service);
+ // For incognito, we use a non-persistent server bound cert store.
+ net::ServerBoundCertService* server_bound_cert_service =
+ new net::ServerBoundCertService(
+ new net::DefaultServerBoundCertStore(NULL));
+ set_server_bound_cert_service(server_bound_cert_service);
+ main_context->set_server_bound_cert_service(server_bound_cert_service);
main_context->set_cookie_store(
new net::CookieMonster(NULL, profile_params->cookie_monster_delegate));
@@ -219,7 +219,7 @@ void OffTheRecordProfileIOData::LazyInitializeInternal(
net::HttpCache* cache =
new net::HttpCache(main_context->host_resolver(),
main_context->cert_verifier(),
- main_context->origin_bound_cert_service(),
+ main_context->server_bound_cert_service(),
main_context->transport_security_state(),
main_context->proxy_service(),
GetSSLSessionCacheShard(),
« no previous file with comments | « chrome/browser/net/ssl_config_service_manager_pref.cc ('k') | chrome/browser/profiles/profile_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698